@@ -283,13 +283,14 @@ about_cb (GtkWidget * widget, gpointer data)
 			 "name", _(APP_NAME_LONG),
 			 "version", VERSION,
 			 "copyright",
-			 "Copyright \xc2\xa9 1998-2007 Ian Peters",
+			 "Copyright \xc2\xa9 1998-2008 Ian Peters",
                          "license", license,
-                         "comments", _("A disk flipping game derived from Reversi."),
+                         "comments", _("A disk flipping game derived from Reversi.\n\nIagno is a part of GNOME Games."),
 			 "authors", authors,
                          "documenters", documenters,
 			 "translator-credits", _("translator-credits"),
 			 "logo-icon-name", "gnome-iagno",
+			 "website-label", _("GNOME Games web site"),
                          "website", "http://www.gnome.org/projects/gnome-games/",
 			 "wrap-license", TRUE,
                          NULL);
